import React from 'react';
import { BrowserRouter as Router, Route, Switch } from "react-router-dom";

import Navigation from './Navigation';
import Footer from './Footer';
import Home from './Home';

// Maps
import Pigeon from './maps/Pigeon';
import MapGL from './maps/MapGL';
import Leaflet from './maps/Leaflet';
import Google from './maps/Google';
import Mapbox from './maps/Mapbox';

import Pigeons from './test/Pigeons';
import MapGLs from './test/MapGLs';
import Leaflets from './test/Leaflets';
import Googles from './test/Googles';
import Mapboxes from './test/Mapboxes';

import {calcDistance} from './helpers/distance';
import {longitude, latitude} from "./config/variables";


export class App extends React.Component{
  constructor(props) {
    super(props)

    this.state = {
      mapConfig: {
        zoom: 15,
        path: [[latitude, longitude]],
        coords: [latitude, longitude],
        defaultZoom: 15,
        distance: 0,
      }
    }
  }

  updateMapState = (key, value) => {
    let mapConfigCopy = JSON.parse(JSON.stringify(this.state.mapConfig));
    mapConfigCopy[key] = value;
    this.setState({mapConfig: mapConfigCopy})
  }

  getDistance = () => {
    let dst = calcDistance(this.state.mapConfig.path)
    this.updateMapState("distance", dst)
  }

  render(){
    return (
      <div>
        <Router>
          <Navigation />
          <div className="wrapper">
            <Switch>
              <Route path="/" exact component={Home} />

              <Route exact path="/pigeon-map" render={() =>
                <Pigeon
                  mapConfig={this.state.mapConfig}
                  updateMapState={this.updateMapState}
                  getDistance={this.getDistance}
                />}
              />
              <Route path="/pigeon-map/test" exact component={Pigeons} />

              <Route path="/map-gl" exact component={MapGL} />
              <Route path="/map-gl/test" exact component={MapGLs} />

              <Route path="/leaflet" exact component={Leaflet} />
              <Route path="/leaflet/test" exact component={Leaflets} />

              <Route path="/google-map" exact component={Google} />
              <Route path="/google-map/test" exact component={Googles} />

              <Route path="/mapbox" exact component={Mapbox} />
              <Route path="/mapbox/test" exact component={Mapboxes} />

            </Switch>
          </div>
          <Footer />
        </Router>
      </div>
    )
  }
}